@@ -112,7 +112,11 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
         try:
             execfile(filename, dict)
         except IOError, e:
-            if e.errno <> errno.ENOENT: raise
+            # Ignore missing files, but log other errors
+            if e.errno == errno.ENOENT:
+                pass
+            else:
+                syslog('error', 'IOError reading list extension: %s', e)
         else:
             func = dict.get('extend')
             if func:
@@ -683,6 +687,7 @@ class MailList(HTMLFormatter, Deliverer, ListAdmin,
         crafting a message to the member informing them of the invitation.
         """
         invitee = userdesc.address
+        Utils.ValidateEmail(invitee)
         requestaddr = self.GetRequestEmail()
         # Hack alert!  Squirrel away a flag that only invitations have, so
         # that we can do something slightly different when an invitation
