@@ -18,8 +18,13 @@ przyczania si do projektu):
 
 
 W chwili obecnej przetumaczone jest 99% interfejsu subskrybenta i okoo 
-50% interfejsu administracyjnego.
+80% interfejsu administracyjnego. Najbardziej aktualnej wersji szukajcie w
+oficjalnych CVS Mailmana. 
 
-2003-04-19, sawickib
+Do zrobienia:
+- przetumaczenie README.*
+- szlifowanie, polerowania :)
+
+2003-09-25, sawickib
 
 
